==> agent-0.3.0-20170115.090802-1.jar: META-INF/leiningen/clojang/agent/README.md <==
# agent
[![Build Status][travis-badge]][travis]
[![Dependencies Status][deps-badge]][deps]
[![Clojars Project][clojars-badge]][clojars]

*Clojang Node and REPL Start-up*

[![Clojang logo][logo]][logo-large]


#### Contents

* [About](#about-)
* [Usage](#usage-)
* [License](#license-)


## About [&#x219F;](#contents)

The Clojang Agent is intended to perform one significant task and one minor one:

* Start up a JInterface node (in the same way that an Erlang shell or an LFE REPL when the BEAM is started in distributed mode, e.g., ``-sname mynode``)
* Close the splash image that Clojang displays


## Usage [&#x219F;](#contents)

To use the agent, update your ``project.clj`` (either top-level or one of your profiles) to include the following:

```clj
  ...
  :dependencies [
    [clojang/jiface "0.1.1"]
    [clojang/agent "0.1.0"]
    ...]
  :jvm-opts ["-Dnode.sname=clojang"]
  :java-agents [[clojang/agent "0.1.0"]]
  :aot [clojang.agent.startup]
  ...
```


## License [&#x219F;](#contents)

```
Copyright © 2016 Duncan McGreggor

Distributed under the Apache License Version 2.0.
```


<!-- Named page links below: /-->

[travis]: https://travis-ci.org/clojang/agent
[travis-badge]: https://travis-ci.org/clojang/agent.png?branch=master
[deps]: http://jarkeeper.com/clojang/agent
[deps-badge]: http://jarkeeper.com/clojang/agent/status.svg
[clojars]: https://clojars.org/clojang/agent
[clojars-badge]: https://img.shields.io/clojars/v/clojang/agent.svg
[logo]: https://github.com/clojang/resources/blob/master/images/logo-5-250x.png
[logo-large]: https://github.com/clojang/resources/blob/master/images/logo-5-1000x.png

==> agent-0.4.0-20170513.011605-9.jar: META-INF/leiningen/clojang/agent/README.md <==
# agent
[![Build Status][travis-badge]][travis]
[![Dependencies Status][deps-badge]][deps]
[![Clojars Project][clojars-badge]][clojars]

*Clojang Node and REPL Start-up*

[![Clojang logo][logo]][logo-large]


#### Contents

* [About](#about-)
* [Usage](#usage-)
* [Documentation](#documentation-)
* [License](#license-)


## About [&#x219F;](#contents)

The Clojang Agent is intended to perform one significant task and one minor one:

* Start up a JInterface node (in the same way that an Erlang shell or an LFE REPL when the BEAM is started in distributed mode, e.g., ``-sname mynode``)
* Close the splash image that Clojang displays


## Usage [&#x219F;](#contents)

To use the agent, update your ``project.clj`` (either top-level or one of your profiles) to include the following:

```clj
  ...
  :dependencies [
    [clojang/jiface "0.1.1"]
    [clojang/agent "0.1.0"]
    ...]
  :jvm-opts ["-Dnode.sname=clojang"]
  :java-agents [[clojang/agent "0.1.0"]]
  :aot [clojang.agent.startup]
  ...
```


## Documentation [&#x219F;](#contents)

The clojang-agent API reference is available here:

 * http://clojang.github.io/agent


## License [&#x219F;](#contents)

```
Copyright © 2016 Duncan McGreggor

Distributed under the Apache License Version 2.0.
```


<!-- Named page links below: /-->

[travis]: https://travis-ci.org/clojang/agent
[travis-badge]: https://travis-ci.org/clojang/agent.png?branch=master
[deps]: http://jarkeeper.com/clojang/agent
[deps-badge]: http://jarkeeper.com/clojang/agent/status.svg
[clojars]: https://clojars.org/clojang/agent
[clojars-badge]: https://img.shields.io/clojars/v/clojang/agent.svg
[logo]: https://github.com/clojang/resources/blob/master/images/logo-5-250x.png
[logo-large]: https://github.com/clojang/resources/blob/master/images/logo-5-1000x.png
